@@ -30,7 +30,7 @@ class ServiceAccount(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if self.automount_service_account_token:
                 self.res["automountServiceAccountToken"] = self.automount_service_account_token
             if self.image_pull_secrets:
